import React, { useImperativeHandle, useRef } from 'react';
import purebem from 'purebem';
import toNumber from './utils/toNumber';
import './FoundationTextbox.scss';

function noop() {}

export default React.forwardRef(function FoundationTextbox(_ref, ref) {
  var _ref$autoFocus = _ref.autoFocus,
      autoFocus = _ref$autoFocus === void 0 ? false : _ref$autoFocus,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$hasErrors = _ref.hasErrors,
      errors = _ref$hasErrors === void 0 ? false : _ref$hasErrors,
      _ref$inputMode = _ref.inputMode,
      inputMode = _ref$inputMode === void 0 ? null : _ref$inputMode,
      _ref$maxLength = _ref.maxLength,
      maxLength = _ref$maxLength === void 0 ? void 0 : _ref$maxLength,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
      _ref$placeholder = _ref.placeholder,
      placeholder = _ref$placeholder === void 0 ? '' : _ref$placeholder,
      _ref$symbol = _ref.symbol,
      symbol = _ref$symbol === void 0 ? null : _ref$symbol,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value;
  var block = purebem('foundation-textbox');

  function isNumericInput() {
    return ['float', 'float-negative-only', 'float-positive-only', 'integer', 'integer-negative-only', 'integer-positive-only'].includes(type);
  }

  var inputRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      focus: function focus() {
        if (inputRef.current !== null) {
          inputRef.current.focus();
        }
      },
      select: function select() {
        if (inputRef.current !== null) {
          inputRef.current.select();
        }
      }
    };
  });

  var handleChange = function handleChange(evt) {
    var newText = evt.target.value;

    var _ref2 = isNumericInput() ? toNumber(newText, type) : {
      isValid: true,
      value: newText
    },
        isValid = _ref2.isValid,
        value = _ref2.value;

    if (isValid) {
      onChange({
        rawValue: newText,
        value: value
      });
    }
  };

  return React.createElement("div", {
    className: block({
      disabled: disabled,
      errors: errors
    })
  }, React.createElement("input", {
    autoFocus: autoFocus,
    className: block('field'),
    disabled: disabled,
    inputMode: inputMode !== null ? inputMode : isNumericInput() ? 'numeric' : void 0,
    maxLength: maxLength,
    onChange: handleChange,
    placeholder: placeholder,
    ref: inputRef,
    type: type,
    value: typeof value !== 'string' ? value.toString() : value
  }), React.createElement("div", {
    className: block('symbol', {
      disabled: disabled,
      visible: symbol !== null
    })
  }, symbol));
});
//# sourceMappingURL=FoundationTextbox.js.map