import removeThousandSeparator from './removeThousandSeparator';
import replaceMinusSign from './replaceMinusSign';

function isInvalidNumber(maxNumberOfDots) {
  return function isInvalid(input) {
    var matches = input.match(/\./g);
    return matches !== null && matches.length > maxNumberOfDots;
  };
}

var isInvalidFloat = isInvalidNumber(1);
var isInvalidInteger = isInvalidNumber(0);

function isValid(input, type, value) {
  if (Number.isNaN(value)) {
    return false;
  }

  switch (type) {
    case 'float':
      return !isInvalidFloat(input);

    case 'float-negative-only':
      return !isInvalidFloat(input) && value <= 0;

    case 'float-positive-only':
      return !isInvalidFloat(input) && value >= 0;

    case 'integer':
      return !isInvalidInteger(input);

    case 'integer-negative-only':
      return !isInvalidInteger(input) && value <= 0;

    case 'integer-positive-only':
      return !isInvalidInteger(input) && value >= 0;

    default:
      return true;
  }
}

function canHaveLeadingCommaOrDot(type) {
  return ['float', 'float-positive-only'].includes(type);
}

function hasLeadingCommaOrDot(input) {
  return /^[,|.]$/.test(input);
}

function canHaveLeadingMinus(type) {
  return !['float-positive-only', 'integer-positive-only'].includes(type);
}

function hasLeadingMinus(input) {
  return input.length === 1 && input.startsWith('-');
}

export default function toNumber(input, type) {
  if (canHaveLeadingCommaOrDot(type) && hasLeadingCommaOrDot(input) || canHaveLeadingMinus(type) && hasLeadingMinus(input)) {
    return {
      value: 0,
      isValid: true
    };
  }

  var replacedInput = replaceMinusSign(removeThousandSeparator(input)).replace(',', '.'); // Let's allow `,` regardless of locale.

  var value = Number(replacedInput);

  if (!isValid(replacedInput, type, value)) {
    return {
      value: '',
      isValid: false
    };
  }

  return {
    value: value,
    isValid: true
  };
}
//# sourceMappingURL=toNumber.js.map